==> gimmebio.covid-0.1.1-py3-none-any.whl: gimmebio/covid/constants.py <==

GENOMES = {
    ('Influenza_A', 'GCF_000865085.1'): 'ftp://ftp.ncbi.nlm.nih.gov/genomes/refseq/viral/Influenza_A_virus/reference/GCF_000865085.1_ViralMultiSegProj15622/GCF_000865085.1_ViralMultiSegProj15622_genomic.fna.gz',
    ('Influenza_B','GCF_000820495.2'): 'ftp://ftp.ncbi.nlm.nih.gov/genomes/refseq/viral/Influenza_B_virus/latest_assembly_versions/GCF_000820495.2_ViralMultiSegProj14656/GCF_000820495.2_ViralMultiSegProj14656_genomic.fna.gz',
    ('Influenza_C', 'GCF_000856665.10'): 'ftp://ftp.ncbi.nlm.nih.gov/genomes/refseq/viral/Influenza_C_virus/reference/GCF_000856665.10_ViralMultiSegProj15055/GCF_000856665.10_ViralMultiSegProj15055_genomic.fna.gz',
    ('Influenza_D', 'GCF_002867775.1'): 'ftp://ftp.ncbi.nlm.nih.gov/genomes/refseq/viral/Influenza_D_virus/latest_assembly_versions/GCF_002867775.1_ASM286777v1/GCF_002867775.1_ASM286777v1_genomic.fna.gz',
    ('Rhinovirus_A', 'GCF_000862245.1'): 'ftp://ftp.ncbi.nlm.nih.gov/genomes/refseq/viral/Rhinovirus_A/latest_assembly_versions/GCF_000862245.1_ViralProj15330/GCF_000862245.1_ViralProj15330_genomic.fna.gz',
    ('Rhinovirus_B' 'GCF_000861265.1'): 'ftp://ftp.ncbi.nlm.nih.gov/genomes/refseq/viral/Rhinovirus_B/latest_assembly_versions/GCF_000861265.1_ViralProj15309/GCF_000861265.1_ViralProj15309_genomic.fna.gz',
    ('Rhinovirus_C', 'GCF_000872325.1'): 'ftp://ftp.ncbi.nlm.nih.gov/genomes/refseq/viral/Rhinovirus_C/latest_assembly_versions/GCF_000872325.1_ViralProj27901/GCF_000872325.1_ViralProj27901_genomic.fna.gz',
    ('Hepatitis_B','GCF_000861825.2'): 'ftp://ftp.ncbi.nlm.nih.gov/genomes/refseq/viral/Hepatitis_B_virus/latest_assembly_versions/GCF_000861825.2_ViralProj15428/GCF_000861825.2_ViralProj15428_genomic.fna.gz',
    ('Norwalk', 'GCF_000868425.1'): 'ftp://ftp.ncbi.nlm.nih.gov/genomes/refseq/viral/Norwalk_virus/reference/GCF_000868425.1_ViralProj17577/GCF_000868425.1_ViralProj17577_genomic.fna.gz',
    ('Measles', 'GCF_000854845.1'): 'ftp://ftp.ncbi.nlm.nih.gov/genomes/refseq/viral/Measles_morbillivirus/reference/GCF_000854845.1_ViralProj15025/GCF_000854845.1_ViralProj15025_genomic.fna.gz',
    ('Human_immunodeficiency_virus_1','GCF_000864765.1'): 'ftp://ftp.ncbi.nlm.nih.gov/genomes/refseq/viral/Human_immunodeficiency_virus_1/reference/GCF_000864765.1_ViralProj15476/GCF_000864765.1_ViralProj15476_genomic.fna.gz',
    ('Human_immunodeficiency_virus_2','GCF_000856385.1'): 'ftp://ftp.ncbi.nlm.nih.gov/genomes/refseq/viral/Human_immunodeficiency_virus_2/latest_assembly_versions/GCF_000856385.1_ViralProj14991/GCF_000856385.1_ViralProj14991_genomic.fna.gz',
    ('Human_papillomavirus', 'GCF_001274345.1'): 'ftp://ftp.ncbi.nlm.nih.gov/genomes/refseq/viral/Human_papillomavirus/latest_assembly_versions/GCF_001274345.1_ViralProj293723/GCF_001274345.1_ViralProj293723_genomic.fna.gz',
    ('Human_mastadenovirus_A', 'GCF_000846805.1'): 'ftp://ftp.ncbi.nlm.nih.gov/genomes/refseq/viral/Human_mastadenovirus_A/reference/GCF_000846805.1_ViralProj14517/GCF_000846805.1_ViralProj14517_genomic.fna.gz',
    ('Human_mastadenovirus_B', 'GCF_000857085.1'): 'ftp://ftp.ncbi.nlm.nih.gov/genomes/refseq/viral/Human_mastadenovirus_B/reference/GCF_000857085.1_ViralProj15150/GCF_000857085.1_ViralProj15150_genomic.fna.gz',
    ('Coronavirus_HKU15', 'GCF_002816235.1'): 'https://ftp.ncbi.nlm.nih.gov/genomes/refseq/viral/Coronavirus_HKU15/latest_assembly_versions/GCF_002816235.1_ASM281623v1/GCF_002816235.1_ASM281623v1_cds_from_genomic.fna.gz',
    ('Human_coronavirus_229E', 'GCF_001500975.1'): 'https://ftp.ncbi.nlm.nih.gov/genomes/refseq/viral/Human_coronavirus_229E/latest_assembly_versions/GCF_001500975.1_ViralProj306529/GCF_001500975.1_ViralProj306529_genomic.fna.gz',
    ('Human_coronavirus_HKU1', 'GCF_000858765.1'): 'https://ftp.ncbi.nlm.nih.gov/genomes/refseq/viral/Human_coronavirus_HKU1/latest_assembly_versions/GCF_000858765.1_ViralProj15139/GCF_000858765.1_ViralProj15139_genomic.fna.gz',	
    ('Human_coronavirus_NL63', 'GCF_000853865.1'): 'https://ftp.ncbi.nlm.nih.gov/genomes/refseq/viral/Human_coronavirus_NL63/latest_assembly_versions/GCF_000853865.1_ViralProj14960/GCF_000853865.1_ViralProj14960_genomic.fna.gz',
    ('Severe_acute_respiratory_syndrome-related_coronavirus', 'GCF_000864885.1'): 'https://ftp.ncbi.nlm.nih.gov/genomes/refseq/viral/Severe_acute_respiratory_syndrome-related_coronavirus/latest_assembly_versions/GCF_000864885.1_ViralProj15500/GCF_000864885.1_ViralProj15500_genomic.fna.gz',
    ('Severe_acute_respiratory_syndrome-related_coronavirus', 'GCF_009858895.2'): 'https://ftp.ncbi.nlm.nih.gov/genomes/refseq/viral/Severe_acute_respiratory_syndrome-related_coronavirus/latest_assembly_versions/GCF_009858895.2_ASM985889v3/GCF_009858895.2_ASM985889v3_genomic.fna.gz',
    ('Middle_East_respiratory_syndrome-related_coronavirus', 'GCF_000901155.1'): 'https://ftp.ncbi.nlm.nih.gov/genomes/refseq/viral/Middle_East_respiratory_syndrome-related_coronavirus/latest_assembly_versions/GCF_000901155.1_ViralProj183710/GCF_000901155.1_ViralProj183710_genomic.fna.gz',
    ('Respiratory_syncytial_virus', 'GCF_000856445.1'): 'https://ftp.ncbi.nlm.nih.gov/genomes/refseq/viral/Respiratory_syncytial_virus/latest_assembly_versions/GCF_000856445.1_ViralProj15004/GCF_000856445.1_ViralProj15004_genomic.fna.gz',
	
}

FILE_FIELD_DELIM = '___'

FASTA_EXTENSIONS = ['.fna.gz', '.fa.gz']
CONCAT_FASTA = 'all_concat.fa'
BLAST_INDEX = 'covid_blast_index'

==> gimmebio.covid-0.1.2-py3-none-any.whl: gimmebio/covid/constants.py <==

GENOMES = {
    ('Influenza_A', 'GCF_000865085.1'): 'ftp://ftp.ncbi.nlm.nih.gov/genomes/refseq/viral/Influenza_A_virus/reference/GCF_000865085.1_ViralMultiSegProj15622/GCF_000865085.1_ViralMultiSegProj15622_genomic.fna.gz',
    ('Influenza_B', 'GCF_000820495.2'): 'ftp://ftp.ncbi.nlm.nih.gov/genomes/refseq/viral/Influenza_B_virus/latest_assembly_versions/GCF_000820495.2_ViralMultiSegProj14656/GCF_000820495.2_ViralMultiSegProj14656_genomic.fna.gz',
    ('Influenza_C', 'GCF_000856665.10'): 'ftp://ftp.ncbi.nlm.nih.gov/genomes/refseq/viral/Influenza_C_virus/reference/GCF_000856665.10_ViralMultiSegProj15055/GCF_000856665.10_ViralMultiSegProj15055_genomic.fna.gz',
    ('Influenza_D', 'GCF_002867775.1'): 'ftp://ftp.ncbi.nlm.nih.gov/genomes/refseq/viral/Influenza_D_virus/latest_assembly_versions/GCF_002867775.1_ASM286777v1/GCF_002867775.1_ASM286777v1_genomic.fna.gz',
    ('Rhinovirus_A', 'GCF_000862245.1'): 'ftp://ftp.ncbi.nlm.nih.gov/genomes/refseq/viral/Rhinovirus_A/latest_assembly_versions/GCF_000862245.1_ViralProj15330/GCF_000862245.1_ViralProj15330_genomic.fna.gz',
    ('Rhinovirus_B', 'GCF_000861265.1'): 'ftp://ftp.ncbi.nlm.nih.gov/genomes/refseq/viral/Rhinovirus_B/latest_assembly_versions/GCF_000861265.1_ViralProj15309/GCF_000861265.1_ViralProj15309_genomic.fna.gz',
    ('Rhinovirus_C', 'GCF_000872325.1'): 'ftp://ftp.ncbi.nlm.nih.gov/genomes/refseq/viral/Rhinovirus_C/latest_assembly_versions/GCF_000872325.1_ViralProj27901/GCF_000872325.1_ViralProj27901_genomic.fna.gz',
    ('Hepatitis_B','GCF_000861825.2'): 'ftp://ftp.ncbi.nlm.nih.gov/genomes/refseq/viral/Hepatitis_B_virus/latest_assembly_versions/GCF_000861825.2_ViralProj15428/GCF_000861825.2_ViralProj15428_genomic.fna.gz',
    ('Norwalk', 'GCF_000868425.1'): 'ftp://ftp.ncbi.nlm.nih.gov/genomes/refseq/viral/Norwalk_virus/reference/GCF_000868425.1_ViralProj17577/GCF_000868425.1_ViralProj17577_genomic.fna.gz',
    ('Measles', 'GCF_000854845.1'): 'ftp://ftp.ncbi.nlm.nih.gov/genomes/refseq/viral/Measles_morbillivirus/reference/GCF_000854845.1_ViralProj15025/GCF_000854845.1_ViralProj15025_genomic.fna.gz',
    ('Human_immunodeficiency_virus_1','GCF_000864765.1'): 'ftp://ftp.ncbi.nlm.nih.gov/genomes/refseq/viral/Human_immunodeficiency_virus_1/reference/GCF_000864765.1_ViralProj15476/GCF_000864765.1_ViralProj15476_genomic.fna.gz',
    ('Human_immunodeficiency_virus_2','GCF_000856385.1'): 'ftp://ftp.ncbi.nlm.nih.gov/genomes/refseq/viral/Human_immunodeficiency_virus_2/latest_assembly_versions/GCF_000856385.1_ViralProj14991/GCF_000856385.1_ViralProj14991_genomic.fna.gz',
    ('Human_papillomavirus', 'GCF_001274345.1'): 'ftp://ftp.ncbi.nlm.nih.gov/genomes/refseq/viral/Human_papillomavirus/latest_assembly_versions/GCF_001274345.1_ViralProj293723/GCF_001274345.1_ViralProj293723_genomic.fna.gz',
    ('Human_mastadenovirus_A', 'GCF_000846805.1'): 'ftp://ftp.ncbi.nlm.nih.gov/genomes/refseq/viral/Human_mastadenovirus_A/reference/GCF_000846805.1_ViralProj14517/GCF_000846805.1_ViralProj14517_genomic.fna.gz',
    ('Human_mastadenovirus_B', 'GCF_000857085.1'): 'ftp://ftp.ncbi.nlm.nih.gov/genomes/refseq/viral/Human_mastadenovirus_B/reference/GCF_000857085.1_ViralProj15150/GCF_000857085.1_ViralProj15150_genomic.fna.gz',
    ('Coronavirus_HKU15', 'GCF_002816235.1'): 'https://ftp.ncbi.nlm.nih.gov/genomes/refseq/viral/Coronavirus_HKU15/latest_assembly_versions/GCF_002816235.1_ASM281623v1/GCF_002816235.1_ASM281623v1_cds_from_genomic.fna.gz',
    ('Human_coronavirus_229E', 'GCF_001500975.1'): 'https://ftp.ncbi.nlm.nih.gov/genomes/refseq/viral/Human_coronavirus_229E/latest_assembly_versions/GCF_001500975.1_ViralProj306529/GCF_001500975.1_ViralProj306529_genomic.fna.gz',
    ('Human_coronavirus_HKU1', 'GCF_000858765.1'): 'https://ftp.ncbi.nlm.nih.gov/genomes/refseq/viral/Human_coronavirus_HKU1/latest_assembly_versions/GCF_000858765.1_ViralProj15139/GCF_000858765.1_ViralProj15139_genomic.fna.gz',	
    ('Human_coronavirus_NL63', 'GCF_000853865.1'): 'https://ftp.ncbi.nlm.nih.gov/genomes/refseq/viral/Human_coronavirus_NL63/latest_assembly_versions/GCF_000853865.1_ViralProj14960/GCF_000853865.1_ViralProj14960_genomic.fna.gz',
    ('Severe_acute_respiratory_syndrome-related_coronavirus', 'GCF_000864885.1'): 'https://ftp.ncbi.nlm.nih.gov/genomes/refseq/viral/Severe_acute_respiratory_syndrome-related_coronavirus/latest_assembly_versions/GCF_000864885.1_ViralProj15500/GCF_000864885.1_ViralProj15500_genomic.fna.gz',
    ('Severe_acute_respiratory_syndrome-related_coronavirus', 'GCF_009858895.2'): 'https://ftp.ncbi.nlm.nih.gov/genomes/refseq/viral/Severe_acute_respiratory_syndrome-related_coronavirus/latest_assembly_versions/GCF_009858895.2_ASM985889v3/GCF_009858895.2_ASM985889v3_genomic.fna.gz',
    ('Middle_East_respiratory_syndrome-related_coronavirus', 'GCF_000901155.1'): 'https://ftp.ncbi.nlm.nih.gov/genomes/refseq/viral/Middle_East_respiratory_syndrome-related_coronavirus/latest_assembly_versions/GCF_000901155.1_ViralProj183710/GCF_000901155.1_ViralProj183710_genomic.fna.gz',
    ('Respiratory_syncytial_virus', 'GCF_000856445.1'): 'https://ftp.ncbi.nlm.nih.gov/genomes/refseq/viral/Respiratory_syncytial_virus/latest_assembly_versions/GCF_000856445.1_ViralProj15004/GCF_000856445.1_ViralProj15004_genomic.fna.gz',
	
}

FILE_FIELD_DELIM = '___'

FASTA_EXTENSIONS = ['.fna.gz', '.fa.gz']
CONCAT_FASTA = 'all_concat.fa'
BLAST_INDEX = 'covid_blast_index'
